@@ -56,10 +56,12 @@ def test_proc_sys_stats(testdir):
 
         @pytest.fixture(scope="module")
         def sshd(request, salt_factories):
-            return salt_factories.spawn_sshd_server(request, "sshd")
+            factory = salt_factories.get_sshd_daemon("sshd")
+            with factory.started():
+                yield factory
 
         def test_one(sshd):
-            assert sshd.is_alive()
+            assert sshd.is_running()
         """
     )
     res = testdir.runpytest("-vv", "--sys-stats")
@@ -70,7 +72,7 @@ def test_proc_sys_stats(testdir):
             "* Processes Statistics *",
             "* System  -  CPU: * %   MEM: * % (Virtual Memory)*",
             "* Test Suite Run  -  CPU: * %   MEM: * % (RSS) * CHILD PROCS: *",
-            "* sshd  -  CPU: * %   MEM: * % (RSS)",
+            "* SSHD  -  CPU: * %   MEM: * % (RSS)*",
             "* 1 passed in *",
         ]
     )
